https://svn.lrde.epita.fr/svn/oln/trunk/milena
Index: ChangeLog
from Thierry Geraud <thierry.geraud(a)lrde.epita.fr>
Renaming some concepts with more explicit and longer names.
* mln/core/concept/piter.hh,
* mln/core/concept/genpoint.hh,
* mln/core/concept/psite.hh,
* mln/core/concept/viter.hh,
* mln/core/concept/doc/genpoint.hh,
* mln/core/concept/doc/piter.hh,
* mln/core/concept/doc/viter.hh,
* mln/core/concept/doc/genpixel.hh,
* mln/core/concept/genpixel.hh: Rename respectively as...
* mln/core/concept/point_iterator.hh,
* mln/core/concept/generalized_point.hh,
* mln/core/concept/point_site.hh,
* mln/core/concept/value_iterator.hh,
* mln/core/concept/doc/generalized_point.hh,
* mln/core/concept/doc/point_iterator.hh,
* mln/core/concept/doc/value_iterator.hh,
* mln/core/concept/doc/generalized_pixel.hh,
* mln/core/concept/generalized_pixel.hh: ...these.
* mln/convert/to_dpoint.hh,
* mln/geom/pmin_pmax.hh,
* mln/core/dpoints_piter.hh,
* mln/core/psubset.hh,
* mln/core/box.hh,
* mln/core/psubset_piter.hh,
* mln/core/rectangle2d.hh,
* mln/core/box_piter.hh,
* mln/core/window.hh,
* mln/core/dpoints_pixter.hh,
* mln/core/internal/image_adaptor.hh,
* mln/core/internal/image_base.hh,
* mln/core/internal/piter_adaptor.hh,
* mln/core/pixel.hh,
* mln/core/hline2d.hh,
* mln/core/neighb.hh,
* mln/core/concept/value_set.hh,
* mln/core/concept/point.hh,
* mln/core/concept/pixel_iterator.hh,
* mln/core/concept/point_set.hh,
* mln/core/concept/doc/image.hh,
* mln/core/concept/doc/value_set.hh,
* mln/core/concept/doc/pixel_iterator.hh,
* mln/core/concept/doc/point_set.hh,
* mln/core/concept/doc/window.hh,
* mln/core/concept/doc/neighborhood.hh,
* mln/core/vline2d.hh,
* mln/level/approx/median.hh,
* mln/value/lut_vec.hh,
* mln/value/viter.hh,
* mln/value/set.hh: Update.
* TODO: Update.
TODO | 17 +++++++--
mln/convert/to_dpoint.hh | 6 +--
mln/core/box.hh | 6 +--
mln/core/box_piter.hh | 10 ++---
mln/core/concept/doc/generalized_pixel.hh | 12 +++---
mln/core/concept/doc/generalized_point.hh | 10 ++---
mln/core/concept/doc/image.hh | 8 ++--
mln/core/concept/doc/neighborhood.hh | 6 +--
mln/core/concept/doc/pixel_iterator.hh | 2 -
mln/core/concept/doc/point_iterator.hh | 16 ++++----
mln/core/concept/doc/point_set.hh | 6 +--
mln/core/concept/doc/value_iterator.hh | 10 ++---
mln/core/concept/doc/value_set.hh | 4 +-
mln/core/concept/doc/window.hh | 6 +--
mln/core/concept/generalized_pixel.hh | 14 +++----
mln/core/concept/generalized_point.hh | 54 +++++++++++++++---------------
mln/core/concept/pixel_iterator.hh | 4 +-
mln/core/concept/point.hh | 4 +-
mln/core/concept/point_iterator.hh | 16 ++++----
mln/core/concept/point_set.hh | 2 -
mln/core/concept/point_site.hh | 16 ++++----
mln/core/concept/value_iterator.hh | 20 +++++------
mln/core/concept/value_set.hh | 2 -
mln/core/dpoints_piter.hh | 12 +++---
mln/core/dpoints_pixter.hh | 10 ++---
mln/core/hline2d.hh | 4 +-
mln/core/internal/image_adaptor.hh | 2 -
mln/core/internal/image_base.hh | 6 +--
mln/core/internal/piter_adaptor.hh | 6 +--
mln/core/neighb.hh | 4 +-
mln/core/pixel.hh | 4 +-
mln/core/psubset.hh | 6 +--
mln/core/psubset_piter.hh | 2 -
mln/core/rectangle2d.hh | 4 +-
mln/core/vline2d.hh | 4 +-
mln/core/window.hh | 6 +--
mln/geom/pmin_pmax.hh | 4 +-
mln/level/approx/median.hh | 2 -
mln/value/lut_vec.hh | 4 +-
mln/value/set.hh | 4 +-
mln/value/viter.hh | 6 +--
41 files changed, 175 insertions(+), 166 deletions(-)
Index: TODO
--- TODO (revision 1026)
+++ TODO (working copy)
@@ -25,17 +25,13 @@
in Fast_Image: memcpy and memset-like methods (?)
.offset() into GenPixel
-notion of low-quantization
-vset and .values() in Image
built-in op objects -> reverse lhs/rhs
* renaming
-GenPixel, GenPoint, Psite, Piter: longer name (?)
mlc into metal
point-wise material: pw::value_of, pw::constant, and pw::variable
-kind-related: mln_value_kind(I) and mln_kind(V)
* clean-up
@@ -52,3 +48,16 @@
border::* and no-op versions if not fast image
arith::inplace_plus et al.
linear:: for convolutions
+
+
+svn mv genpoint.hh generalized_point.hh
+svn mv genpixel.hh generalized_pixel.hh
+svn mv psite.hh point_site.hh
+svn mv viter.hh value_iterator.hh
+svn mv piter.hh point_iterator.hh
+
+
+svn mv doc/genpoint.hh doc/generalized_point.hh
+svn mv doc/genpixel.hh doc/generalized_pixel.hh
+svn mv doc/viter.hh doc/value_iterator.hh
+svn mv doc/piter.hh doc/point_iterator.hh
Index: mln/convert/to_dpoint.hh
--- mln/convert/to_dpoint.hh (revision 1026)
+++ mln/convert/to_dpoint.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Convertions to mln::Dpoint.
*/
-# include <mln/core/concept/genpoint.hh>
+# include <mln/core/concept/generalized_point.hh>
namespace mln
@@ -44,13 +44,13 @@
/// Convert a generalized point \p p into a delta-point.
template <typename P>
- mln_dpoint(P) to_dpoint(const GenPoint<P>& p);
+ mln_dpoint(P) to_dpoint(const Generalized_Point<P>& p);
# ifndef MLN_INCLUDE_ONLY
template <typename P>
- mln_dpoint(P) to_dpoint(const GenPoint<P>& p_)
+ mln_dpoint(P) to_dpoint(const Generalized_Point<P>& p_)
{
const P& p = internal::force_exact<P>(p_);
mln_dpoint(P) tmp;
Index: mln/geom/pmin_pmax.hh
--- mln/geom/pmin_pmax.hh (revision 1026)
+++ mln/geom/pmin_pmax.hh (working copy)
@@ -48,7 +48,7 @@
/// iterator \p p.
template <typename I>
std::pair<mln_point(I), mln_point(I)>
- pmin_pmax(const Piter<I>& p);
+ pmin_pmax(const Point_Iterator<I>& p);
@@ -56,7 +56,7 @@
template <typename I>
std::pair<mln_point(I), mln_point(I)>
- pmin_pmax(Piter<I>& p_)
+ pmin_pmax(Point_Iterator<I>& p_)
{
I& p = exact(p_);
Index: mln/core/dpoints_piter.hh
--- mln/core/dpoints_piter.hh (revision 1026)
+++ mln/core/dpoints_piter.hh (working copy)
@@ -33,8 +33,8 @@
* \brief Definition of mln::dpoints_fwd_piter and mln::dpoints_bkd_piter.
*/
-# include <mln/core/concept/piter.hh>
-# include <mln/core/concept/genpoint.hh>
+# include <mln/core/concept/point_iterator.hh>
+# include <mln/core/concept/generalized_point.hh>
namespace mln
@@ -46,7 +46,7 @@
* The parameter \c D is the type of delta-points.
*/
template <typename D>
- class dpoints_fwd_piter : public Piter< dpoints_fwd_piter<D> >
+ class dpoints_fwd_piter : public Point_Iterator< dpoints_fwd_piter<D> >
{
public:
@@ -59,7 +59,7 @@
/// Point associated type.
typedef mln_point(D) point;
- /// Psite associated type.
+ /// Point_Site associated type.
typedef point psite;
/// Coordinate associated type.
@@ -72,7 +72,7 @@
*/
template <typename Dps, typename Pref>
dpoints_fwd_piter(const Dps& dps, // FIXME: explicitly set_of_<D>?
- const GenPoint<Pref>& p_ref);
+ const Generalized_Point<Pref>& p_ref);
/// Convertion to point.
operator mln_point(D) () const;
@@ -117,7 +117,7 @@
template <typename D>
template <typename Dps, typename Pref>
dpoints_fwd_piter<D>::dpoints_fwd_piter(const Dps& dps,
- const GenPoint<Pref>& p_ref)
+ const Generalized_Point<Pref>& p_ref)
: dps_(exact(dps).vec()),
p_ref_(* internal::force_exact<Pref>(p_ref).pointer_())
{
Index: mln/core/psubset.hh
--- mln/core/psubset.hh (revision 1026)
+++ mln/core/psubset.hh (working copy)
@@ -67,17 +67,17 @@
template <typename S, typename F>
struct psubset : public Point_Set< psubset<S,F> >
{
- /// Psite associated type.
+ /// Point_Site associated type.
typedef mln_psite(S) psite;
/// Point associated type.
typedef mln_point(S) point;
- /// Forward Piter associated type.
+ /// Forward Point_Iterator associated type.
typedef psubset_fwd_piter_<S,F> fwd_piter;
- /// Backward Piter associated type.
+ /// Backward Point_Iterator associated type.
typedef internal::fixme bkd_piter;
Index: mln/core/box.hh
--- mln/core/box.hh (revision 1026)
+++ mln/core/box.hh (working copy)
@@ -54,7 +54,7 @@
struct box_ : public Box< box_<P> >,
public internal::box_impl_< P::dim, mln_coord(P), box_<P> >
{
- /*! \brief Psite associated type.
+ /*! \brief Point_Site associated type.
*/
typedef P psite;
@@ -62,11 +62,11 @@
*/
typedef P point;
- /*! \brief Forward Piter associated type.
+ /*! \brief Forward Point_Iterator associated type.
*/
typedef box_fwd_piter_<P> fwd_piter;
- /*! \brief Backward Piter associated type.
+ /*! \brief Backward Point_Iterator associated type.
*/
typedef box_bkd_piter_<P> bkd_piter;
Index: mln/core/psubset_piter.hh
--- mln/core/psubset_piter.hh (revision 1026)
+++ mln/core/psubset_piter.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Definition of iterators on points of psubsetes.
*/
-# include <mln/core/concept/piter.hh>
+# include <mln/core/concept/point_iterator.hh>
# include <mln/core/internal/piter_adaptor.hh>
# include <mln/core/psubset.hh>
Index: mln/core/rectangle2d.hh
--- mln/core/rectangle2d.hh (revision 1026)
+++ mln/core/rectangle2d.hh (working copy)
@@ -62,12 +62,12 @@
/// Dpoint associated type.
typedef dpoint2d dpoint;
- /*! \brief Piter type to browse a rectangle such as: "for each row
+ /*! \brief Point_Iterator type to browse a rectangle such as: "for each row
* (increasing), for each column (increasing)."
*/
typedef dpoints_fwd_piter<dpoint2d> fwd_qiter;
- /*! \brief Piter type to browse a rectangle such as: "for each row
+ /*! \brief Point_Iterator type to browse a rectangle such as: "for each row
* (decreasing), for each column (decreasing)."
*/
typedef internal::fixme bkd_qiter;
Index: mln/core/box_piter.hh
--- mln/core/box_piter.hh (revision 1026)
+++ mln/core/box_piter.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Definition of iterators on points of boxes.
*/
-# include <mln/core/concept/piter.hh>
+# include <mln/core/concept/point_iterator.hh>
# include <mln/core/concept/box.hh>
@@ -47,14 +47,14 @@
* \see mln::box_
*/
template <typename P>
- class box_fwd_piter_ : public Piter< box_fwd_piter_<P> >
+ class box_fwd_piter_ : public Point_Iterator< box_fwd_piter_<P> >
{
public:
/// Space dimension.
enum { dim = P::dim };
- /// Psite associated type.
+ /// Point_Site associated type.
typedef P psite;
/// Point associated type.
@@ -107,14 +107,14 @@
* \see mln::box_
*/
template <typename P>
- class box_bkd_piter_ : public Piter< box_bkd_piter_<P> >
+ class box_bkd_piter_ : public Point_Iterator< box_bkd_piter_<P> >
{
public:
/// Space dimension.
enum { dim = P::dim };
- /// Psite associated type.
+ /// Point_Site associated type.
typedef P psite;
/// Point associated type.
Index: mln/core/window.hh
--- mln/core/window.hh (revision 1026)
+++ mln/core/window.hh (working copy)
@@ -34,7 +34,7 @@
*/
# include <mln/core/concept/window.hh>
-# include <mln/core/concept/genpoint.hh>
+# include <mln/core/concept/generalized_point.hh>
# include <mln/core/internal/set_of.hh>
# include <mln/core/dpoint.hh>
# include <mln/core/box.hh>
@@ -67,12 +67,12 @@
/// Dpoint associated type.
typedef D dpoint;
- /*! \brief Piter type to browse the points of a generic window
+ /*! \brief Point_Iterator type to browse the points of a generic window
* w.r.t. the ordering of delta-points.
*/
typedef dpoints_fwd_piter<D> fwd_qiter;
- /*! \brief Piter type to browse the points of a generic window
+ /*! \brief Point_Iterator type to browse the points of a generic window
* w.r.t. the reverse ordering of delta-points.
*/
typedef internal::fixme bkd_qiter;
Index: mln/core/dpoints_pixter.hh
--- mln/core/dpoints_pixter.hh (revision 1026)
+++ mln/core/dpoints_pixter.hh (working copy)
@@ -38,7 +38,7 @@
# include <vector>
# include <mln/core/concept/pixel_iterator.hh>
-# include <mln/core/concept/genpixel.hh>
+# include <mln/core/concept/generalized_pixel.hh>
# include <mln/core/internal/pixel_impl.hh>
@@ -70,7 +70,7 @@
template <typename Dps, typename Pref>
dpoints_fwd_pixter(I& image,
const Dps& dps,
- const GenPoint<Pref>& p_ref);
+ const Generalized_Point<Pref>& p_ref);
/*! \brief Constructor.
*
@@ -81,7 +81,7 @@
template <typename Dps, typename Pref>
dpoints_fwd_pixter(I& image,
const Dps& dps,
- const GenPixel<Pref>& p_ref);
+ const Generalized_Pixel<Pref>& p_ref);
/// Start an iteration.
void start();
@@ -134,7 +134,7 @@
template <typename Dps, typename Pref>
dpoints_fwd_pixter<I>::dpoints_fwd_pixter(I& image,
const Dps& dps,
- const GenPoint<Pref>& p_ref)
+ const Generalized_Point<Pref>& p_ref)
: super(image)
{
mln_precondition(image.has_data());
@@ -148,7 +148,7 @@
template <typename Dps, typename Pref>
dpoints_fwd_pixter<I>::dpoints_fwd_pixter(I& image,
const Dps& dps,
- const GenPixel<Pref>& p_ref)
+ const Generalized_Pixel<Pref>& p_ref)
: super(image)
{
mln_precondition(image.has_data());
Index: mln/core/internal/image_adaptor.hh
--- mln/core/internal/image_adaptor.hh (revision 1026)
+++ mln/core/internal/image_adaptor.hh (working copy)
@@ -51,7 +51,7 @@
typename S = mln_pset(I) >
struct image_adaptor_ : public internal::image_base_< S, E >
{
- /// Psite associated type.
+ /// Point_Site associated type.
typedef mln_psite(S) psite;
/// Point_Set associated type.
Index: mln/core/internal/image_base.hh
--- mln/core/internal/image_base.hh (revision 1026)
+++ mln/core/internal/image_base.hh (working copy)
@@ -70,7 +70,7 @@
/// Point_Set associated type.
typedef S pset;
- /// Psite associated type.
+ /// Point_Site associated type.
typedef mln_psite(S) psite;
/// Point associated type.
@@ -84,10 +84,10 @@
typedef mln_coord(point) coord;
- /// Forward Piter associated type.
+ /// Forward Point_Iterator associated type.
typedef mln_fwd_piter(S) fwd_piter;
- /// Backward Piter associated type.
+ /// Backward Point_Iterator associated type.
typedef mln_bkd_piter(S) bkd_piter;
Index: mln/core/internal/piter_adaptor.hh
--- mln/core/internal/piter_adaptor.hh (revision 1026)
+++ mln/core/internal/piter_adaptor.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Definition of iterators on points of boxes.
*/
-# include <mln/core/concept/piter.hh>
+# include <mln/core/concept/point_iterator.hh>
# include <mln/core/concept/box.hh>
@@ -49,14 +49,14 @@
* parameter E is the exact type.
*/
template <typename Pi, typename E>
- class piter_adaptor_ : public Piter<E>
+ class piter_adaptor_ : public Point_Iterator<E>
{
public:
/// Space dimension.
enum { dim = Pi::dim };
- /// Psite associated type.
+ /// Point_Site associated type.
typedef mln_psite(Pi) psite;
/// Point associated type.
Index: mln/core/pixel.hh
--- mln/core/pixel.hh (revision 1026)
+++ mln/core/pixel.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Definition of the generic pixel class mln::pixel.
*/
-# include <mln/core/concept/genpixel.hh>
+# include <mln/core/concept/generalized_pixel.hh>
# include <mln/core/internal/pixel_impl.hh>
@@ -47,7 +47,7 @@
*/
template <typename I>
struct pixel : public Object< pixel<I> >,
- public GenPixel< pixel<I> >,
+ public Generalized_Pixel< pixel<I> >,
internal::pixel_impl_< I, pixel<I> >
{
/// Constructor.
Index: mln/core/hline2d.hh
--- mln/core/hline2d.hh (revision 1026)
+++ mln/core/hline2d.hh (working copy)
@@ -60,12 +60,12 @@
/// Dpoint associated type.
typedef dpoint2d dpoint;
- /*! \brief Piter type to browse a hline such as: "for each row
+ /*! \brief Point_Iterator type to browse a hline such as: "for each row
* (increasing), for each column (increasing)."
*/
typedef dpoints_fwd_piter<dpoint2d> fwd_qiter;
- /*! \brief Piter type to browse a hline such as: "for each row
+ /*! \brief Point_Iterator type to browse a hline such as: "for each row
* (decreasing), for each column (decreasing)."
*/
typedef internal::fixme bkd_qiter;
Index: mln/core/neighb.hh
--- mln/core/neighb.hh (revision 1026)
+++ mln/core/neighb.hh (working copy)
@@ -58,12 +58,12 @@
/// Dpoint associated type.
typedef D dpoint;
- /*! \brief Piter type to browse the points of a generic
+ /*! \brief Point_Iterator type to browse the points of a generic
* neighborhood w.r.t. the ordering of delta-points.
*/
typedef dpoints_fwd_piter<D> fwd_niter;
- /*! \brief Piter type to browse the points of a generic
+ /*! \brief Point_Iterator type to browse the points of a generic
* neighborhood w.r.t. the reverse ordering of delta-points.
*/
typedef dpoints_bkd_piter<D> bkd_niter;
Index: mln/core/concept/value_set.hh
--- mln/core/concept/value_set.hh (revision 1026)
+++ mln/core/concept/value_set.hh (working copy)
@@ -32,7 +32,7 @@
* \brief Definition of the concept of mln::Value_Set.
*/
-# include <mln/core/concept/viter.hh>
+# include <mln/core/concept/value_iterator.hh>
namespace mln
Index: mln/core/concept/point.hh
--- mln/core/concept/point.hh (revision 1026)
+++ mln/core/concept/point.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Definition of the concept of mln::Point.
*/
-# include <mln/core/concept/psite.hh>
+# include <mln/core/concept/point_site.hh>
namespace mln
@@ -47,7 +47,7 @@
* discrete square grid of the 2D plane.
*/
template <typename P>
- struct Point : public Psite<P>
+ struct Point : public Point_Site<P>
{
/*! \brief The associated point type is itself.
*/
Index: mln/core/concept/pixel_iterator.hh
--- mln/core/concept/pixel_iterator.hh (revision 1026)
+++ mln/core/concept/pixel_iterator.hh (working copy)
@@ -34,7 +34,7 @@
*/
# include <mln/core/concept/iterator.hh>
-# include <mln/core/concept/genpixel.hh>
+# include <mln/core/concept/generalized_pixel.hh>
namespace mln
@@ -51,7 +51,7 @@
*/
template <typename E>
struct Pixel_Iterator : public Iterator<E>,
- public GenPixel<E>
+ public Generalized_Pixel<E>
{
/*
typedef lvalue;
Index: mln/core/concept/point_set.hh
--- mln/core/concept/point_set.hh (revision 1026)
+++ mln/core/concept/point_set.hh (working copy)
@@ -34,7 +34,7 @@
*/
# include <mln/core/concept/point.hh>
-# include <mln/core/concept/piter.hh>
+# include <mln/core/concept/point_iterator.hh>
namespace mln
Index: mln/core/concept/doc/image.hh
--- mln/core/concept/doc/image.hh (revision 1026)
+++ mln/core/concept/doc/image.hh (working copy)
@@ -127,8 +127,8 @@
*/
typedef void point;
- /*! \brief Psite associated type.
- * \invariant This type has to derive from mln::Psite.
+ /*! \brief Point_Site associated type.
+ * \invariant This type has to derive from mln::Point_Site.
*/
typedef void psite;
@@ -144,12 +144,12 @@
/*! \brief Forward point iterator associated type.
- * \invariant This type has to derive from mln::Piter.
+ * \invariant This type has to derive from mln::Point_Iterator.
*/
typedef void fwd_piter;
/*! \brief Backward point iterator associated type.
- * \invariant This type has to derive from mln::Piter.
+ * \invariant This type has to derive from mln::Point_Iterator.
*/
typedef void bkd_piter;
Index: mln/core/concept/doc/value_set.hh
--- mln/core/concept/doc/value_set.hh (revision 1026)
+++ mln/core/concept/doc/value_set.hh (working copy)
@@ -46,11 +46,11 @@
*/
typedef void value;
- /*! \brief Forward Viter associated type.
+ /*! \brief Forward Value_Iterator associated type.
*/
typedef void fwd_viter;
- /*! \brief Backward Viter associated type.
+ /*! \brief Backward Value_Iterator associated type.
*/
typedef void bkd_viter;
Index: mln/core/concept/doc/pixel_iterator.hh
--- mln/core/concept/doc/pixel_iterator.hh (revision 1026)
+++ mln/core/concept/doc/pixel_iterator.hh (working copy)
@@ -41,7 +41,7 @@
*/
template <typename E>
struct Pixel_Iterator : public Iterator<E>,
- public GenPixel<E>
+ public Generalized_Pixel<E>
{
/*! \brief Type returned by the read-write dereference operator.
*/
Index: mln/core/concept/doc/point_set.hh
--- mln/core/concept/doc/point_set.hh (revision 1026)
+++ mln/core/concept/doc/point_set.hh (working copy)
@@ -46,15 +46,15 @@
*/
typedef void point;
- /*! \brief Psite associated type.
+ /*! \brief Point_Site associated type.
*/
typedef void psite;
- /*! \brief Forward Piter associated type.
+ /*! \brief Forward Point_Iterator associated type.
*/
typedef void fwd_piter;
- /*! \brief Backward Piter associated type.
+ /*! \brief Backward Point_Iterator associated type.
*/
typedef void bkd_piter;
Index: mln/core/concept/doc/window.hh
--- mln/core/concept/doc/window.hh (revision 1026)
+++ mln/core/concept/doc/window.hh (working copy)
@@ -45,17 +45,17 @@
template <typename E>
struct Window : public Object<E>
{
- /*! \brief Piter type associated to this window to browse its
+ /*! \brief Point_Iterator type associated to this window to browse its
* points.
*/
typedef void qiter;
- /*! \brief Piter type associated to this window to browse its
+ /*! \brief Point_Iterator type associated to this window to browse its
* points in a forward way.
*/
typedef void fwd_qiter;
- /*! \brief Piter type associated to this window to browse its
+ /*! \brief Point_Iterator type associated to this window to browse its
* points in a backward way.
*/
typedef void bkd_qiter;
Index: mln/core/concept/doc/neighborhood.hh
--- mln/core/concept/doc/neighborhood.hh (revision 1026)
+++ mln/core/concept/doc/neighborhood.hh (working copy)
@@ -42,17 +42,17 @@
template <typename E>
struct Neighborhood : public Object<E>
{
- /*! \brief Piter type associated to this neighborhood to browse
+ /*! \brief Point_Iterator type associated to this neighborhood to browse
* neighbors.
*/
typedef void niter;
- /*! \brief Piter type associated to this neighborhood to browse
+ /*! \brief Point_Iterator type associated to this neighborhood to browse
* neighbors in a forward way.
*/
typedef void fwd_niter;
- /*! \brief Piter type associated to this neighborhood to browse
+ /*! \brief Point_Iterator type associated to this neighborhood to browse
* neighbors in a backward way.
*/
typedef void bkd_niter;
Index: mln/core/vline2d.hh
--- mln/core/vline2d.hh (revision 1026)
+++ mln/core/vline2d.hh (working copy)
@@ -62,12 +62,12 @@
/// Dpoint associated type.
typedef dpoint2d dpoint;
- /*! \brief Piter type to browse a vline such as: "for each row
+ /*! \brief Point_Iterator type to browse a vline such as: "for each row
* (increasing), for each column (increasing)."
*/
typedef dpoints_fwd_piter<dpoint2d> fwd_qiter;
- /*! \brief Piter type to browse a vline such as: "for each row
+ /*! \brief Point_Iterator type to browse a vline such as: "for each row
* (decreasing), for each column (decreasing)."
*/
typedef internal::fixme bkd_qiter;
Index: mln/level/approx/median.hh
--- mln/level/approx/median.hh (revision 1026)
+++ mln/level/approx/median.hh (working copy)
@@ -28,7 +28,7 @@
#ifndef MLN_LEVEL_APPROX_MEDIAN_HH
# define MLN_LEVEL_APPROX_MEDIAN_HH
-/*! \file mln/level/median.hh
+/*! \file mln/level/approx/median.hh
*
* \brief Approximates of some median filters of an image.
*/
Index: mln/value/lut_vec.hh
--- mln/value/lut_vec.hh (revision 1026)
+++ mln/value/lut_vec.hh (working copy)
@@ -63,10 +63,10 @@
/// Value associated type.
typedef T value;
- /// Forward Viter associated type.
+ /// Forward Value_Iterator associated type.
typedef fwd_viter_< lut_vec<S,T> > fwd_viter;
- /// Backward Viter associated type.
+ /// Backward Value_Iterator associated type.
typedef bkd_viter_< lut_vec<S,T> > bkd_viter;
/// Give the \p i-th value.
Index: mln/value/viter.hh
--- mln/value/viter.hh (revision 1026)
+++ mln/value/viter.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Definition of iterators on value sets.
*/
-# include <mln/core/concept/viter.hh>
+# include <mln/core/concept/value_iterator.hh>
@@ -49,7 +49,7 @@
* The parameter \c S is the type of value set.
*/
template <typename S>
- struct fwd_viter_ : public Viter< fwd_viter_<S> >
+ struct fwd_viter_ : public Value_Iterator< fwd_viter_<S> >
{
/// Value associated type.
typedef mln_value(S) value;
@@ -86,7 +86,7 @@
* The parameter \c S is the type of value set.
*/
template <typename S>
- struct bkd_viter_ : public Viter< bkd_viter_<S> >
+ struct bkd_viter_ : public Value_Iterator< bkd_viter_<S> >
{
/// Value associated type.
typedef mln_value(S) value;
Index: mln/value/set.hh
--- mln/value/set.hh (revision 1026)
+++ mln/value/set.hh (working copy)
@@ -58,10 +58,10 @@
/// Value associated type.
typedef T value;
- /// Forward Viter associated type.
+ /// Forward Value_Iterator associated type.
typedef fwd_viter_< set_<T> > fwd_viter;
- /// Backward Viter associated type.
+ /// Backward Value_Iterator associated type.
typedef bkd_viter_< set_<T> > bkd_viter;
/// Test if \p v belongs to this set: always true!
Index: mln/core/concept/value_iterator.hh
--- mln/core/concept/value_iterator.hh (revision 1026)
+++ mln/core/concept/value_iterator.hh (working copy)
@@ -28,13 +28,13 @@
#ifndef MLN_CORE_CONCEPT_VITER_HH
# define MLN_CORE_CONCEPT_VITER_HH
-/*! \file mln/core/concept/viter.hh
+/*! \file mln/core/concept/value_iterator.hh
*
* \brief Definition of the concept of mln::Viter.
*/
# include <mln/core/concept/iterator.hh>
-# include <mln/core/concept/genpoint.hh>
+# include <mln/core/concept/generalized_point.hh>
namespace mln
@@ -46,11 +46,11 @@
* An iterator on values is an iterator that browse over a set of
* values.
*
* \see mln::doc::Viter for a complete documentation of this class
* contents.
*/
template <typename E>
- struct Viter : public Iterator<E>
+ struct Value_Iterator : public Iterator<E>
{
/*
typedef value;
@@ -58,7 +58,7 @@
*/
protected:
- Viter();
+ Value_Iterator();
};
@@ -72,17 +72,17 @@
*
* \return The modified output stream \p ostr.
*
- * \relates mln::Viter
+ * \relates mln::Value_Iterator
*/
template <typename E>
- std::ostream& operator<<(std::ostream& ostr, const Viter<E>&
v);
+ std::ostream& operator<<(std::ostream& ostr, const
Value_Iterator<E>& v);
# ifndef MLN_INCLUDE_ONLY
template <typename E>
- Viter<E>::Viter()
+ Value_Iterator<E>::Value_Iterator()
{
typedef mln_value(E) value;
value (E::*m)() const = & E::operator value;
@@ -90,7 +90,7 @@
}
template <typename E>
- std::ostream& operator<<(std::ostream& ostr, const Viter<E>&
v)
+ std::ostream& operator<<(std::ostream& ostr, const
Value_Iterator<E>& v)
{
mln_precondition(exact(v).is_valid());
@@ -28,13 +28,13 @@
*
- * \brief Definition of the concept of mln::Viter.
+ * \brief Definition of the concept of mln::Value_Iterator.
*/
# include <mln/core/concept/iterator.hh>
@@ -46,11 +46,11 @@
* values.
*
- * \see mln::doc::Viter for a complete documentation of this class
+ * \see mln::doc::Value_Iterator for a complete documentation of this class
* contents.
*/
return ostr << mln_value(E)(exact(v));
Index: mln/core/concept/generalized_pixel.hh
--- mln/core/concept/generalized_pixel.hh (revision 1026)
+++ mln/core/concept/generalized_pixel.hh (working copy)
@@ -28,7 +28,7 @@
#ifndef MLN_CORE_CONCEPT_GENPIXEL_HH
# define MLN_CORE_CONCEPT_GENPIXEL_HH
-/*! \file mln/core/concept/genpixel.hh
+/*! \file mln/core/concept/generalized_pixel.hh
*
* \brief Definition of the concept of mln::Genpixel.
*/
@@ -40,21 +40,21 @@
namespace mln
{
- // FIXME: \class GenPixel GenPixel.hh "mln/core/concept/doc/GenPixel.hh"
+ // FIXME: \class Generalized_Pixel Generalized_Pixel.hh
"mln/core/concept/doc/Generalized_Pixel.hh"
/*! \brief Base class for implementation classes that are pixels or that
* have the behavior of pixels.
*
* "GenPixel" is "Generalized Pixel" for short.
*
* \warning This class does \em not derive from mln::Object; it is
* for use as a parallel hierarchy.
*
* \see mln::doc::GenPixel for a complete documentation of this
* class contents.
*/
template <typename E>
- struct GenPixel
+ struct Generalized_Pixel
{
/*
typedef value;
@@ -64,14 +64,14 @@
value** address_() const;
*/
protected:
- GenPixel();
+ Generalized_Pixel();
};
# ifndef MLN_INCLUDE_ONLY
template <typename E>
- GenPixel<E>::GenPixel()
+ Generalized_Pixel<E>::Generalized_Pixel()
{
typedef mln_value(E) value;
typedef mln_rvalue(E) rvalue;
@@ -40,21 +40,21 @@
* have the behavior of pixels.
*
- * "GenPixel" is "Generalized Pixel" for short.
+ * "Generalized_Pixel" is "Generalized Pixel" for short.
*
* \warning This class does \em not derive from mln::Object; it is
@@ -40,21 +40,21 @@
* for use as a parallel hierarchy.
*
- * \see mln::doc::GenPixel for a complete documentation of this
+ * \see mln::doc::Generalized_Pixel for a complete documentation of this
* class contents.
*/
Index: mln/core/concept/generalized_point.hh
--- mln/core/concept/generalized_point.hh (revision 1026)
+++ mln/core/concept/generalized_point.hh (working copy)
@@ -28,8 +28,8 @@
#ifndef MLN_CORE_CONCEPT_GENPOINT_HH
# define MLN_CORE_CONCEPT_GENPOINT_HH
/*! \file mln/core/concept/genpoint.hh
* \brief Definition of the concept of mln::GenPoint.
*/
# include <mlc/equal.hh>
# include <mlc/same_point.hh>
@@ -42,21 +42,21 @@
namespace mln
{
- // FIXME: \class GenPoint genpoint.hh "mln/core/concept/doc/genpoint.hh"
+ // FIXME: \class Generalized_Point generalized_point.hh
"mln/core/concept/doc/generalized_point.hh"
/*! \brief Base class for implementation classes that are points or that
* have the behavior of points.
*
* "GenPoint" is "Generalized Point" for short.
*
* \warning This class does \em not derive from mln::Object; it is
* for use as a parallel hierarchy.
*
* \see mln::doc::GenPoint for a complete documentation of this
* class contents.
*/
template <typename E>
- struct GenPoint
+ struct Generalized_Point
{
/*
@@ -75,7 +75,7 @@
*/
protected:
- GenPoint();
+ Generalized_Point();
};
@@ -93,10 +93,10 @@
* \return True if both generalized points have the same
* coordinates, otherwise false.
*
- * \relates mln::GenPoint
+ * \relates mln::Generalized_Point
*/
template <typename Pl, typename Pr>
- bool operator=(const GenPoint<Pl>& lhs, const GenPoint<Pr>& rhs);
+ bool operator=(const Generalized_Point<Pl>& lhs, const
Generalized_Point<Pr>& rhs);
/*! \brief Ordering "less than" comparison between a couple of generalized
@@ -117,10 +117,10 @@
* \return True if \p lhs is before \p rhs in the sense of the
* coordinates lexicographic comparison, otherwise false.
*
- * \relates mln::GenPoint
+ * \relates mln::Generalized_Point
*/
template <typename Pl, typename Pr>
- bool operator<(const GenPoint<Pl>& lhs, const GenPoint<Pr>&
rhs);
+ bool operator<(const Generalized_Point<Pl>& lhs, const
Generalized_Point<Pr>& rhs);
/*! \brief Difference between a couple of generalized point \p lhs and \p
@@ -142,11 +142,11 @@
* \return A delta-point (temporary object).
*
* \see mln::Dpoint
- * \relates mln::GenPoint
+ * \relates mln::Generalized_Point
*/
template <typename Pl, typename Pr>
mln_dpoint(Pl)
- operator-(const GenPoint<Pl>& lhs, const GenPoint<Pr>& rhs);
+ operator-(const Generalized_Point<Pl>& lhs, const
Generalized_Point<Pr>& rhs);
/*! \brief Add a delta-point \p rhs to a generalized point \p lhs.
@@ -160,14 +160,14 @@
* \return A point (temporary object).
*
* \see mln::Dpoint
- * \relates mln::GenPoint
+ * \relates mln::Generalized_Point
*
* \todo Introduce the notion of "generalized dpoint" and
* add the more general extra operator+(GenPoint, GenDpoint).
*/
template <typename P>
mln_point(P)
- operator+(const GenPoint<P>& lhs, const mln_dpoint(P)& rhs);
+ operator+(const Generalized_Point<P>& lhs, const mln_dpoint(P)& rhs);
/*! \brief Substract a delta-point \p rhs to a generalized point \p lhs.
@@ -181,11 +181,11 @@
* \return A point (temporary object).
*
* \see mln::Dpoint
- * \relates mln::GenPoint
+ * \relates mln::Generalized_Point
*/
template <typename P>
mln_point(P)
- operator-(const GenPoint<P>& lhs, const mln_dpoint(P)& rhs);
+ operator-(const Generalized_Point<P>& lhs, const mln_dpoint(P)& rhs);
/*! \brief Print a generalized point \p p into the output stream \p
@@ -196,10 +196,10 @@
*
* \return The modified output stream \p ostr.
*
- * \relates mln::GenPoint
+ * \relates mln::Generalized_Point
*/
template <typename P>
- std::ostream& operator<<(std::ostream& ostr, const GenPoint<P>&
p);
+ std::ostream& operator<<(std::ostream& ostr, const
Generalized_Point<P>& p);
@@ -207,7 +207,7 @@
template <typename E>
- GenPoint<E>::GenPoint()
+ Generalized_Point<E>::Generalized_Point()
{
int dim = E::dim;
mln_invariant(dim > 0);
@@ -223,7 +223,7 @@
template <typename Pl, typename Pr>
- bool operator=(const GenPoint<Pl>& lhs, const GenPoint<Pr>& rhs)
+ bool operator=(const Generalized_Point<Pl>& lhs, const
Generalized_Point<Pr>& rhs)
{
// FIXME: mlc::same_grid<Pl, Pr>::check();
const Pl& lhs_ = internal::force_exact<Pl>(lhs);
@@ -236,7 +236,7 @@
}
template <typename Pl, typename Pr>
- bool operator<(const GenPoint<Pl>& lhs, const GenPoint<Pr>&
rhs)
+ bool operator<(const Generalized_Point<Pl>& lhs, const
Generalized_Point<Pr>& rhs)
{
// FIXME: mlc::same_grid<Pl, Pr>::check();
const Pl& lhs_ = internal::force_exact<Pl>(lhs);
@@ -252,7 +252,7 @@
template <typename Pl, typename Pr>
mln_dpoint(Pl)
- operator-(const GenPoint<Pl>& lhs, const GenPoint<Pr>& rhs)
+ operator-(const Generalized_Point<Pl>& lhs, const
Generalized_Point<Pr>& rhs)
{
mlc::equal<mln_dpoint(Pl), mln_dpoint(Pr)>::check();
// FIXME: mlc::same_grid<Pl, Pr>::check();
@@ -268,7 +268,7 @@
template <typename P>
mln_point(P)
- operator+(const GenPoint<P>& lhs, const mln_dpoint(P)& rhs)
+ operator+(const Generalized_Point<P>& lhs, const mln_dpoint(P)& rhs)
{
const P& lhs_ = internal::force_exact<P>(lhs);
mln_point(P) tmp;
@@ -279,7 +279,7 @@
template <typename P>
mln_point(P)
- operator-(const GenPoint<P>& lhs, const mln_dpoint(P)& rhs)
+ operator-(const Generalized_Point<P>& lhs, const mln_dpoint(P)& rhs)
{
const P& lhs_ = internal::force_exact<P>(lhs);
mln_point(P) tmp;
@@ -289,7 +289,7 @@
}
template <typename P>
- std::ostream& operator<<(std::ostream& ostr, const GenPoint<P>&
p)
+ std::ostream& operator<<(std::ostream& ostr, const
Generalized_Point<P>& p)
{
const P& p_ = internal::force_exact<P>(p);
@@ -28,8 +28,8 @@
#ifndef MLN_CORE_CONCEPT_GENPOINT_HH
# define MLN_CORE_CONCEPT_GENPOINT_HH
-/*! \file mln/core/concept/genpoint.hh
- * \brief Definition of the concept of mln::GenPoint.
+/*! \file mln/core/concept/generalized_point.hh
+ * \brief Definition of the concept of mln::Generalized_Point.
*/
# include <mlc/equal.hh>
@@ -42,21 +42,21 @@
* have the behavior of points.
*
- * "GenPoint" is "Generalized Point" for short.
+ * "Generalized_Point" is "Generalized Point" for short.
*
* \warning This class does \em not derive from mln::Object; it is
@@ -42,21 +42,21 @@
* for use as a parallel hierarchy.
*
- * \see mln::doc::GenPoint for a complete documentation of this
+ * \see mln::doc::Generalized_Point for a complete documentation of this
* class contents.
*/
@@ -160,14 +160,14 @@
*
* \todo Introduce the notion of "generalized dpoint" and
- * add the more general extra operator+(GenPoint, GenDpoint).
+ * add the more general extra operator+(Generalized_Point, GenDpoint).
*/
template <typename P>
Index: mln/core/concept/point_iterator.hh
--- mln/core/concept/point_iterator.hh (revision 1026)
+++ mln/core/concept/point_iterator.hh (working copy)
@@ -28,13 +28,13 @@
#ifndef MLN_CORE_CONCEPT_PITER_HH
# define MLN_CORE_CONCEPT_PITER_HH
-/*! \file mln/core/concept/piter.hh
+/*! \file mln/core/concept/point_iterator.hh
*
* \brief Definition of the concept of mln::Piter.
*/
# include <mln/core/concept/iterator.hh>
-# include <mln/core/concept/genpoint.hh>
+# include <mln/core/concept/generalized_point.hh>
namespace mln
@@ -46,12 +46,12 @@
* An iterator on points is an iterator that browse over a set of
* points.
*
* \see mln::doc::Piter for a complete documentation of this class
* contents.
*/
template <typename E>
- struct Piter : public Iterator<E>,
- public GenPoint<E>
+ struct Point_Iterator : public Iterator<E>,
+ public Generalized_Point<E>
{
/*
typedef psite;
@@ -59,14 +59,14 @@
*/
protected:
- Piter();
+ Point_Iterator();
};
# ifndef MLN_INCLUDE_ONLY
template <typename E>
- Piter<E>::Piter()
+ Point_Iterator<E>::Point_Iterator()
{
typedef mln_psite(E) psite;
psite (E::*m)() const = & E::operator psite;
@@ -28,13 +28,13 @@
*
- * \brief Definition of the concept of mln::Piter.
+ * \brief Definition of the concept of mln::Point_Iterator.
*/
# include <mln/core/concept/iterator.hh>
@@ -46,12 +46,12 @@
* points.
*
- * \see mln::doc::Piter for a complete documentation of this class
+ * \see mln::doc::Point_Iterator for a complete documentation of this class
* contents.
*/
Index: mln/core/concept/doc/value_iterator.hh
--- mln/core/concept/doc/value_iterator.hh (revision 1026)
+++ mln/core/concept/doc/value_iterator.hh (working copy)
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
/*! \file mln/core/concept/doc/viter.hh
* \brief This file documents the concept of mln::Viter.
*/
namespace mln
@@ -35,12 +35,12 @@
namespace doc
{
/*! \brief Documentation class for mln::Viter.
*
- * \see mln::Viter
+ * \see mln::Value_Iterator
*/
template <typename E>
- struct Viter : public Iterator<E>
+ struct Value_Iterator : public Iterator<E>
{
/*! \brief Value associated type.
*/
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file mln/core/concept/doc/viter.hh
- * \brief This file documents the concept of mln::Viter.
+/*! \file mln/core/concept/doc/value_iterator.hh
+ * \brief This file documents the concept of mln::Value_Iterator.
*/
namespace mln
@@ -35,12 +35,12 @@
namespace doc
{
- /*! \brief Documentation class for mln::Viter.
+ /*! \brief Documentation class for mln::Value_Iterator.
*
Index: mln/core/concept/doc/generalized_pixel.hh
--- mln/core/concept/doc/generalized_pixel.hh (revision 1026)
+++ mln/core/concept/doc/generalized_pixel.hh (working copy)
@@ -28,8 +28,8 @@
#ifndef MLN_CORE_CONCEPT_DOC_GENPIXEL_HH
# define MLN_CORE_CONCEPT_DOC_GENPIXEL_HH
/*! \file mln/core/concept/doc/genpixel.hh
* \brief This file documents the concept of mln::GenPixel.
*/
@@ -39,12 +39,12 @@
namespace doc
{
/*! \brief Documentation class for mln::GenPixel.
*
- * \see mln::GenPixel
+ * \see mln::Generalized_Pixel
*/
template <typename E>
- struct GenPixel
+ struct Generalized_Pixel
{
/// Value associated type.
@@ -70,7 +70,7 @@
value** address_() const;
protected:
- GenPixel();
+ Generalized_Pixel();
};
} // end of namespace mln::doc
@@ -28,8 +28,8 @@
#ifndef MLN_CORE_CONCEPT_DOC_GENPIXEL_HH
# define MLN_CORE_CONCEPT_DOC_GENPIXEL_HH
-/*! \file mln/core/concept/doc/genpixel.hh
- * \brief This file documents the concept of mln::GenPixel.
+/*! \file mln/core/concept/doc/generalized_pixel.hh
+ * \brief This file documents the concept of mln::Generalized_Pixel.
*/
@@ -39,12 +39,12 @@
namespace doc
{
- /*! \brief Documentation class for mln::GenPixel.
+ /*! \brief Documentation class for mln::Generalized_Pixel.
*
Index: mln/core/concept/doc/point_iterator.hh
--- mln/core/concept/doc/point_iterator.hh (revision 1026)
+++ mln/core/concept/doc/point_iterator.hh (working copy)
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
/*! \file mln/core/concept/doc/piter.hh
* \brief This file documents the concept of mln::Piter.
*/
namespace mln
@@ -35,16 +35,16 @@
namespace doc
{
/*! \brief Documentation class for mln::Piter.
*
- * \see mln::Piter
+ * \see mln::Point_Iterator
*/
template <typename E>
- struct Piter : public Iterator<E>,
- public GenPoint<E>
+ struct Point_Iterator : public Iterator<E>,
+ public Generalized_Point<E>
{
- /*! \brief Psite associated type.
- * \invariant This type has to derive from mln::Psite.
+ /*! \brief Point_Site associated type.
+ * \invariant This type has to derive from mln::Point_Site.
*/
typedef void psite;
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file mln/core/concept/doc/piter.hh
- * \brief This file documents the concept of mln::Piter.
+/*! \file mln/core/concept/doc/point_iterator.hh
+ * \brief This file documents the concept of mln::Point_Iterator.
*/
namespace mln
@@ -35,16 +35,16 @@
namespace doc
{
- /*! \brief Documentation class for mln::Piter.
+ /*! \brief Documentation class for mln::Point_Iterator.
*
Index: mln/core/concept/doc/generalized_point.hh
--- mln/core/concept/doc/generalized_point.hh (revision 1026)
+++ mln/core/concept/doc/generalized_point.hh (working copy)
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
/*! \file mln/core/concept/doc/genpoint.hh
* \brief This file documents the concept of mln::GenPoint.
*/
namespace mln
@@ -35,12 +35,12 @@
namespace doc
{
/*! \brief Documentation class for mln::GenPoint.
*
- * \see mln::GenPoint
+ * \see mln::Generalized_Point
*/
template <typename E>
- struct GenPoint
+ struct Generalized_Point
{
/*! \var dim
* \brief Dimension of the space.
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file mln/core/concept/doc/genpoint.hh
- * \brief This file documents the concept of mln::GenPoint.
+/*! \file mln/core/concept/doc/generalized_point.hh
+ * \brief This file documents the concept of mln::Generalized_Point.
*/
namespace mln
@@ -35,12 +35,12 @@
namespace doc
{
- /*! \brief Documentation class for mln::GenPoint.
+ /*! \brief Documentation class for mln::Generalized_Point.
*
Index: mln/core/concept/point_site.hh
--- mln/core/concept/point_site.hh (revision 1026)
+++ mln/core/concept/point_site.hh (working copy)
@@ -28,11 +28,11 @@
#ifndef MLN_CORE_CONCEPT_PSITE_HH
# define MLN_CORE_CONCEPT_PSITE_HH
/*! \file mln/core/concept/psite.hh
* \brief Definition of the concept of mln::Psite.
*/
-# include <mln/core/concept/genpoint.hh>
+# include <mln/core/concept/generalized_point.hh>
namespace mln
@@ -46,7 +46,7 @@
* is either a point or designates a point: regular points, deriving
* from mln::Point, are point sites, yet some point sites are not
* points.) A point site has the behavior expected from every
* point; see mln::GenPoint.
*
* When a point site is not a point, it is automatically convertible
* to the point it designates.
@@ -61,8 +61,8 @@
* proper point site is a pair (index of run, index within the run).
*/
template <typename E>
- struct Psite : public Object<E>,
- public GenPoint<E>
+ struct Point_Site : public Object<E>,
+ public Generalized_Point<E>
{
/*
const point* pointer_() const
@@ -72,14 +72,14 @@
*/
protected:
- Psite();
+ Point_Site();
};
# ifndef MLN_INCLUDE_ONLY
template <typename E>
- Psite<E>::Psite()
+ Point_Site<E>::Point_Site()
{
}
@@ -28,11 +28,11 @@
#ifndef MLN_CORE_CONCEPT_PSITE_HH
# define MLN_CORE_CONCEPT_PSITE_HH
-/*! \file mln/core/concept/psite.hh
- * \brief Definition of the concept of mln::Psite.
+/*! \file mln/core/concept/point_site.hh
+ * \brief Definition of the concept of mln::Point_Site.
*/
@@ -46,7 +46,7 @@
* from mln::Point, are point sites, yet some point sites are not
* points.) A point site has the behavior expected from every
- * point; see mln::GenPoint.
+ * point; see mln::Generalized_Point.
*
* When a point site is not a point, it is automatically convertible